@@ -45,16 +45,19 @@ def traversing_nested_lists(json_response,data_to_obfuscate):
 
 def encryption(item):
     item=item
+    salt = "3ELT@k&Devc!4yxAg!X2"   
 
     if isinstance(item,type(None)) or item=="None" or item=="": #Check if item to key contains personal data
         return item #if not, the item is returned unencrypted
 
     elif isinstance(item,str): #check if item is text string
-        item_bytes=bytes(item, 'utf-8')  #string is turned into bytes
+        item_salted=item+salt
+        item_bytes=bytes(item_salted, 'utf-8')  #string is turned into bytes
     
     elif isinstance(item,int): #check if item is integrer
         item=str(item) #To turn data into hashable bytes, integers are turned into text
-        item_bytes=bytes(item,'utf-8') #string is turned into bytes
+        item_salted=item+salt
+        item_bytes=bytes(item_salted,'utf-8') #string is turned into bytes
 
     item_encrypted = hashlib.sha256(item_bytes).hexdigest() #item is encrypted with SHA256 algorithm
 
